@@ -1,8 +1,15 @@
+# frozen-string-literal: true
+
 module Sequel
   # Hash of adapters that have been used. The key is the adapter scheme
   # symbol, and the value is the Database subclass.
   ADAPTER_MAP = {}
     
+  # Hash of shared adapters that have been registered.  The key is the
+  # adapter scheme symbol, and the value is the Sequel module containing
+  # the shared adapter.
+  SHARED_ADAPTER_MAP = {}
+
   # Array of all databases to which Sequel has connected.  If you are
   # developing an application that can connect to an arbitrary number of 
   # databases, delete the database objects from this or they will not get
