@@ -12,8 +12,12 @@ describe "pg_array extension" do
   end
 
   before do
-    @db = Sequel.connect('mock://postgres', :quote_identifiers=>false)
-    @db.extend_datasets(Module.new{def supports_timestamp_timezones?; false; end; def supports_timestamp_usecs?; false; end})
+    @db = Sequel.connect('mock://postgres')
+    @db.extend_datasets(Module.new do
+      def supports_timestamp_timezones?; false end
+      def supports_timestamp_usecs?; false; end
+      def quote_identifiers?; false end
+    end)
     @db.extension(:pg_array)
     @m = Sequel::Postgres
     @converter = @m::PG_TYPES
@@ -316,14 +320,9 @@ describe "pg_array extension" do
     Sequel::Postgres::PG_TYPES[1].call('{1}').class.must_equal(Sequel::Postgres::PGArray)
   end
 
-  it "should support registering custom types with :parser=>:json option" do
-    Sequel::Postgres::PGArray.register('foo', :oid=>2, :parser=>:json)
-    Sequel::Postgres::PG_TYPES[2].must_be_kind_of(Sequel::Postgres::PGArray::JSONCreator)
-  end
-
-  it "should support registering converters with :parser=>:json option and blocks" do
-    Sequel::Postgres::PGArray.register('foo', :oid=>4, :parser=>:json){|s| s * 2}
-    Sequel::Postgres::PG_TYPES[4].call('{{1, 2}, {3, 4}}').must_equal [[2, 4], [6, 8]]
+  it "should support registering converters with blocks" do
+    Sequel::Postgres::PGArray.register('foo', :oid=>4){|s| s.to_i * 2}
+    Sequel::Postgres::PG_TYPES[4].call('{{1,2},{3,4}}').must_equal [[2, 4], [6, 8]]
   end
 
   it "should support registering custom types with :array_type option" do
@@ -331,6 +330,11 @@ describe "pg_array extension" do
     @db.literal(Sequel::Postgres::PG_TYPES[3].call('{}')).must_equal "'{}'::blah[]"
   end
 
+  it "should not support registering custom array types on a per-Database basis for frozen databases" do
+    @db.freeze
+    proc{@db.register_array_type('banana', :oid=>7865){|s| s}}.must_raise RuntimeError, TypeError
+  end
+
   it "should support registering custom array types on a per-Database basis" do
     @db.register_array_type('banana', :oid=>7865){|s| s}
     @db.typecast_value(:banana_array, []).class.must_equal(Sequel::Postgres::PGArray)
